@@ -16,6 +16,7 @@
  *******************************************************************************/
 package org.eclipse.debug.internal.ui.views.variables.details;
 
+import java.text.MessageFormat;
 import java.util.Iterator;
 import java.util.ResourceBundle;
 
@@ -109,8 +110,6 @@ import org.eclipse.ui.texteditor.IAbstractTextEditorHelpContextIds;
 import org.eclipse.ui.texteditor.ITextEditorActionConstants;
 import org.eclipse.ui.texteditor.ITextEditorActionDefinitionIds;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * This detail pane uses a source viewer to display detailed information about the current
  * selection.  It incorporates a large number of actions into its context menu.  It is the
@@ -171,8 +170,8 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 	 */
 	class DetailJob extends Job implements IValueDetailListener {
 
-		private IStructuredSelection fElements;
-		private IDebugModelPresentation fModel;
+		private final IStructuredSelection fElements;
+		private final IDebugModelPresentation fModel;
 		private boolean fFirst = true;
 		// whether a result was collected
 		private boolean fComputed = false;
@@ -1055,7 +1054,7 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 	 */
 	class FindReplaceTargetWrapper implements IFindReplaceTarget{
 
-		private IFindReplaceTarget fTarget;
+		private final IFindReplaceTarget fTarget;
 
 		/**
 		 * Constructor
