@@ -23,7 +23,6 @@ import static org.eclipse.equinox.internal.provisional.p2.director.RequestStatus
 import static org.eclipse.equinox.internal.provisional.p2.director.RequestStatus.REMOVED;
 
 import java.lang.reflect.Method;
-import java.net.URI;
 import java.util.*;
 import java.util.stream.Stream;
 import org.eclipse.core.runtime.*;
@@ -47,7 +46,7 @@ import org.eclipse.equinox.p2.query.*;
 import org.eclipse.osgi.util.NLS;
 
 public class SimplePlanner implements IPlanner {
-	private static boolean DEBUG = Tracing.DEBUG_PLANNER_OPERANDS;
+	private static final boolean DEBUG = Tracing.DEBUG_PLANNER_OPERANDS;
 
 	private static final int ExpandWork = 12;
 	private static final String INCLUDE_PROFILE_IUS = "org.eclipse.equinox.p2.internal.profileius"; //$NON-NLS-1$
@@ -84,10 +83,10 @@ public class SimplePlanner implements IPlanner {
 		}
 
 		Map<IInstallableUnit, RequestStatus>[] changes = buildDetailedSuccess(toState, changeRequest);
-		Map<IInstallableUnit, RequestStatus> requestChanges = (changes == null) ? null : changes[0];
-		Map<IInstallableUnit, RequestStatus> requestSideEffects = (changes == null) ? null : changes[1];
+		Map<IInstallableUnit, RequestStatus> requestChanges = changes[0];
+		Map<IInstallableUnit, RequestStatus> requestSideEffects = changes[1];
 		IStatus status = convertChangesToStatus(requestChanges, requestSideEffects);
-		QueryableArray plannedState = new QueryableArray(toState.toArray(new IInstallableUnit[toState.size()]));
+		QueryableArray plannedState = new QueryableArray(toState);
 		PlannerStatus plannerStatus = new PlannerStatus(status, null, requestChanges, requestSideEffects, plannedState);
 		plan.setStatus(plannerStatus);
 		plan.setInstallerPlan(installerPlan);
@@ -128,13 +127,11 @@ public class SimplePlanner implements IPlanner {
 			int status = !toState.contains(removed) ? OK : ERROR;
 			requestStatus.put(removed, new RequestStatus(removed, REMOVED, status, null));
 		}
-
 		// Compute the side effect changes (e.g. things installed optionally going away)
-		Iterator<IInstallableUnit> includedIUs = changeRequest.getProfile()
-				.query(new IUProfilePropertyQuery(INCLUSION_RULES, IUProfilePropertyQuery.ANY), null).iterator();
+		IQueryResult<IInstallableUnit> includedIUs = changeRequest.getProfile()
+				.query(new IUProfilePropertyQuery(INCLUSION_RULES, IUProfilePropertyQuery.ANY), null);
 		Map<IInstallableUnit, RequestStatus> sideEffectStatus = new HashMap<>();
-		while (includedIUs.hasNext()) {
-			IInstallableUnit removal = includedIUs.next();
+		for (IInstallableUnit removal : includedIUs) {
 			if (!toState.contains(removal) && !requestStatus.containsKey(removal)) {
 				sideEffectStatus.put(removal, new RequestStatus(removal, REMOVED, INFO, null));
 			}
@@ -158,23 +155,20 @@ public class SimplePlanner implements IPlanner {
 		// for the PDE target platform into a general purpose profile.
 		List<IStatus> forTargets = new ArrayList<>(0);
 		for (Explanation next : explanations) {
-			if (next instanceof MissingIU) {
-				MissingIU missingIU = (MissingIU) next;
-				if (missingIU.req instanceof IRequiredCapability
-						&& missingIU.req.getMatches().getParameters().length == 3
-						&& "A.PDE.Target.Platform".equals(((IRequiredCapability) missingIU.req).getNamespace())) {//$NON-NLS-1$
-					// This IU requires the PDE target platform IU and it is missing.
-					// I.e. this IU is intended only for the PDE target platform.
-					forTargets.add(new Status(ERROR, PI_DIRECTOR, Explanation.getUserReadableName(missingIU.iu)));
-				}
+			if (next instanceof MissingIU missingIU && missingIU.req instanceof IRequiredCapability requiredCapability
+					&& requiredCapability.getMatches().getParameters().length == 3
+					&& "A.PDE.Target.Platform".equals(requiredCapability.getNamespace())) {//$NON-NLS-1$
+				// This IU requires the PDE target platform IU and it is missing.
+				// I.e. this IU is intended only for the PDE target platform.
+				forTargets.add(Status.error(Explanation.getUserReadableName(missingIU.iu)));
 			}
 		}
 		if (!forTargets.isEmpty()) {
 			// The following line could be removed if Bug 309863 is fixed
-			forTargets.add(new Status(ERROR, PI_DIRECTOR, Messages.Director_For_Target_Unselect_Required));
+			forTargets.add(Status.error(Messages.Director_For_Target_Unselect_Required));
 			// Return a multi status with all the IUs that require A.PDE.Target.Platform
-			return new MultiStatus(PI_DIRECTOR, 1, forTargets.stream().toArray(IStatus[]::new),
-					Messages.Director_For_Target, null);
+			return new MultiStatus(PI_DIRECTOR, 1, forTargets.toArray(IStatus[]::new), Messages.Director_For_Target,
+					null);
 		}
 
 		// Use the most specific message for the root of the MultiStatus
@@ -221,19 +215,11 @@ public class SimplePlanner implements IPlanner {
 	}
 
 	private static IStatus buildChangeStatus(RequestStatus rs) {
-		final String change;
-		switch (rs.getInitialRequestType()) {
-		case ADDED:
-			change = "Add"; //$NON-NLS-1$
-			break;
-		case REMOVED:
-			change = "Remove"; //$NON-NLS-1$
-			break;
-		default:
-			change = "UNKNOWN change type " + rs.getInitialRequestType(); //$NON-NLS-1$
-			break;
-		}
-
+		final String change = switch (rs.getInitialRequestType()) {
+		case ADDED -> "Add"; //$NON-NLS-1$
+		case REMOVED -> "Remove"; //$NON-NLS-1$
+		default -> "UNKNOWN change type " + rs.getInitialRequestType(); //$NON-NLS-1$
+		};
 		final IStatus status;
 		if (!rs.isOK()) {
 			String message = NLS.bind(Messages.Director_Unsatisfied_Change, change,
@@ -336,7 +322,7 @@ public class SimplePlanner implements IPlanner {
 		return result;
 	}
 
-	private IInstallableUnit[] gatherAvailableInstallableUnits(IInstallableUnit[] additionalSource,
+	private Collection<IInstallableUnit> gatherAvailableInstallableUnits(List<IInstallableUnit> additionalSource,
 			ProvisioningContext context, IProgressMonitor monitor) {
 		Map<String, IInstallableUnit> resultsMap = new HashMap<>();
 		if (additionalSource != null) {
@@ -364,15 +350,12 @@ public class SimplePlanner implements IPlanner {
 				resultsMap.put(key, iu);
 		}
 		sub.done();
-		Collection<IInstallableUnit> results = resultsMap.values();
-		return results.toArray(new IInstallableUnit[results.size()]);
+		return resultsMap.values();
 	}
 
 	private static boolean hasHigherFidelity(IInstallableUnit iu, IInstallableUnit currentIU) {
-		if (Boolean.parseBoolean(currentIU.getProperty(IInstallableUnit.PROP_PARTIAL_IU))
-				&& !Boolean.parseBoolean(iu.getProperty(IInstallableUnit.PROP_PARTIAL_IU)))
-			return true;
-		return false;
+		return Boolean.parseBoolean(currentIU.getProperty(IInstallableUnit.PROP_PARTIAL_IU))
+				&& !Boolean.parseBoolean(iu.getProperty(IInstallableUnit.PROP_PARTIAL_IU));
 	}
 
 	public SimplePlanner(IProvisioningAgent agent) {
@@ -385,12 +368,8 @@ public class SimplePlanner implements IPlanner {
 	}
 
 	private boolean satisfyMetaRequirements(Map<String, String> props) {
-		if (props == null)
-			return true;
-		if (props.get(CONSIDER_METAREQUIREMENTS) == null
-				|| "true".equalsIgnoreCase(props.get(CONSIDER_METAREQUIREMENTS))) //$NON-NLS-1$
-			return true;
-		return false;
+		return props == null || props.get(CONSIDER_METAREQUIREMENTS) == null
+				|| Boolean.parseBoolean(props.get(CONSIDER_METAREQUIREMENTS));
 	}
 
 	private boolean satisfyMetaRequirements(IProfile p) {
@@ -425,29 +404,21 @@ public class SimplePlanner implements IPlanner {
 			extraIUs.addAll(profileChangeRequest.getRemovals());
 			if (context == null || context.getProperty(INCLUDE_PROFILE_IUS) == null
 					|| context.getProperty(INCLUDE_PROFILE_IUS).equalsIgnoreCase(Boolean.TRUE.toString())) {
-				Iterator<IInstallableUnit> itor = profile.available(QueryUtil.createIUAnyQuery(), null).iterator();
-				while (itor.hasNext()) {
-					extraIUs.add(itor.next());
-				}
+				profile.available(QueryUtil.createIUAnyQuery(), null).forEach(extraIUs::add);
 			}
 
-			IInstallableUnit[] availableIUs = gatherAvailableInstallableUnits(
-					extraIUs.stream().toArray(IInstallableUnit[]::new), context, sub.newChild(ExpandWork / 4));
+			Collection<IInstallableUnit> availableIUs = gatherAvailableInstallableUnits(extraIUs, context,
+					sub.newChild(ExpandWork / 4));
 			Slicer slicer = new Slicer(new QueryableArray(availableIUs), newSelectionContext,
 					satisfyMetaRequirements(profileChangeRequest.getProfileProperties()));
-			IQueryable<IInstallableUnit> slice = slicer
-					.slice(new IInstallableUnit[] { (IInstallableUnit) updatedPlan[0] }, sub.newChild(ExpandWork / 4));
+			IQueryable<IInstallableUnit> slice = slicer.slice(List.of((IInstallableUnit) updatedPlan[0]),
+					sub.newChild(ExpandWork / 4));
 			if (slice == null) {
 				IProvisioningPlan plan = engine.createPlan(profile, context);
 				plan.setStatus(slicer.getStatus());
 				return plan;
 			}
-
-			@SuppressWarnings("unchecked")
-			IQueryable<IInstallableUnit>[] queryables = new IQueryable[] { slice,
-					new QueryableArray(profileChangeRequest.getAdditions().stream().toArray(IInstallableUnit[]::new)) };
-			slice = new CompoundQueryable<>(queryables);
-
+			slice = new CompoundQueryable<>(List.of(slice, new QueryableArray(profileChangeRequest.getAdditions())));
 			Projector projector = new Projector(slice, newSelectionContext, slicer.getNonGreedyIUs(),
 					satisfyMetaRequirements(profileChangeRequest.getProfileProperties()));
 			projector.setUserDefined(profileChangeRequest.getPropertiesToAdd().containsKey("_internal_user_defined_")); //$NON-NLS-1$
@@ -459,6 +430,7 @@ public class SimplePlanner implements IPlanner {
 			case CANCEL: {
 				IProvisioningPlan plan = engine.createPlan(profile, context);
 				plan.setStatus(s);
+				projector.close();
 				return plan;
 			}
 
@@ -469,6 +441,7 @@ public class SimplePlanner implements IPlanner {
 						|| Boolean.parseBoolean(context.getProperty(EXPLANATION))))) {
 					IProvisioningPlan plan = engine.createPlan(profile, context);
 					plan.setStatus(s);
+					projector.close();
 					return plan;
 				}
 
@@ -477,13 +450,14 @@ public class SimplePlanner implements IPlanner {
 				IStatus explanationStatus = convertExplanationToStatus(explanation);
 
 				Map<IInstallableUnit, RequestStatus>[] changes = buildDetailedErrors(profileChangeRequest);
-				Map<IInstallableUnit, RequestStatus> requestChanges = (changes == null) ? null : changes[0];
-				Map<IInstallableUnit, RequestStatus> requestSideEffects = (changes == null) ? null : changes[1];
+				Map<IInstallableUnit, RequestStatus> requestChanges = changes[0];
+				Map<IInstallableUnit, RequestStatus> requestSideEffects = changes[1];
 				PlannerStatus plannerStatus = new PlannerStatus(explanationStatus,
 						new RequestStatus(null, REMOVED, ERROR, explanation), requestChanges, requestSideEffects, null);
 
 				IProvisioningPlan plan = engine.createPlan(profile, context);
 				plan.setStatus(plannerStatus);
+				projector.close();
 				return plan;
 			}
 
@@ -516,17 +490,18 @@ public class SimplePlanner implements IPlanner {
 			// Get the solution for the initial request
 			Object resolutionResult = getSolutionFor(pcr, context, sub.newChild(ExpandWork / 2));
 			// a return value of a plan indicates failure when resolving so return.
-			if (resolutionResult instanceof IProvisioningPlan) {
-				return (IProvisioningPlan) resolutionResult;
+			if (resolutionResult instanceof IProvisioningPlan plan) {
+				return plan;
 			}
 
-			Collection<IInstallableUnit> newState = ((Projector) resolutionResult).extractSolution();
+			Projector projector = (Projector) resolutionResult;
+			Collection<IInstallableUnit> newState = projector.extractSolution();
 			Collection<IInstallableUnit> fullState = new ArrayList<>();
 			fullState.addAll(newState);
-			newState = AttachmentHelper.attachFragments(newState.iterator(),
-					((Projector) resolutionResult).getFragmentAssociation());
+			newState = AttachmentHelper.attachFragments(newState.stream(), projector.getFragmentAssociation());
 
-			IProvisioningPlan temporaryPlan = generatePlan((Projector) resolutionResult, newState, pcr, context);
+			IProvisioningPlan temporaryPlan = generatePlan(projector, newState, pcr, context);
+			projector.close();
 
 			// Create a plan for installing necessary pieces to complete the installation
 			// (e.g touchpoint actions)
@@ -620,7 +595,7 @@ public class SimplePlanner implements IPlanner {
 			sub.setTaskName(Messages.Director_Task_installer_plan);
 			if (profileRegistry == null) {
 				IProvisioningPlan plan = engine.createPlan(initialRequest.getProfile(), initialContext);
-				plan.setStatus(new Status(ERROR, PI_DIRECTOR, Messages.Planner_no_profile_registry));
+				plan.setStatus(Status.error(Messages.Planner_no_profile_registry));
 				return plan;
 			}
 
@@ -641,8 +616,8 @@ public class SimplePlanner implements IPlanner {
 				if (profile.getProfileId().equals(installerProfile.getProfileId())) {
 					if (profile.getTimestamp() != installerProfile.getTimestamp()) {
 						IProvisioningPlan plan = engine.createPlan(initialRequest.getProfile(), initialContext);
-						plan.setStatus(new Status(ERROR, PI_DIRECTOR,
-								NLS.bind(Messages.Planner_profile_out_of_sync, profile.getProfileId())));
+						plan.setStatus(
+								Status.error(NLS.bind(Messages.Planner_profile_out_of_sync, profile.getProfileId())));
 						return plan;
 					}
 					return createInstallerPlanForCohostedCase(profile, initialRequest, initialPlan, unattachedState,
@@ -652,8 +627,10 @@ public class SimplePlanner implements IPlanner {
 			}
 
 			if (satisfyMetaRequirements(profile) && !profile.getProfileId().equals(installerProfile.getProfileId())) {
-				return createInstallerPlanForCohostedCaseFromExternalInstaller(profile, initialRequest, initialPlan,
-						expectedState, initialContext, installerProfile, sub);
+				// co-hosted case from external installer
+				IProvisioningPlan planForProfile = generatePlan(null, expectedState, initialRequest, initialContext);
+				return createInstallerPlanForExternalInstaller(profile, initialRequest, planForProfile, expectedState,
+						initialContext, installerProfile, sub);
 			}
 
 			return createInstallerPlanForExternalInstaller(profile, initialRequest, initialPlan, expectedState,
@@ -676,14 +653,6 @@ public class SimplePlanner implements IPlanner {
 		return thisLocation.getRootLocation().equals(otherLocation.getRootLocation());
 	}
 
-	private IProvisioningPlan createInstallerPlanForCohostedCaseFromExternalInstaller(IProfile profile,
-			ProfileChangeRequest initialRequest, IProvisioningPlan initialPlan, Collection<IInstallableUnit> newState,
-			ProvisioningContext initialContext, IProfile agentProfile, SubMonitor sub) {
-		IProvisioningPlan planForProfile = generatePlan(null, newState, initialRequest, initialContext);
-		return createInstallerPlanForExternalInstaller(profile, initialRequest, planForProfile, newState,
-				initialContext, agentProfile, sub);
-	}
-
 	// Deal with the case where the agent profile is different than the one being
 	// provisioned
 	private IProvisioningPlan createInstallerPlanForExternalInstaller(IProfile targetedProfile,
@@ -708,12 +677,12 @@ public class SimplePlanner implements IPlanner {
 		agentRequest.add(actionsIU);
 		if (previousActionsIU != null)
 			agentRequest.remove(previousActionsIU);
-		Object externalInstallerPlan = getSolutionFor(agentRequest, initialContext, sub.newChild(10));
-		if (externalInstallerPlan instanceof IProvisioningPlan
-				&& ((IProvisioningPlan) externalInstallerPlan).getStatus().getSeverity() == ERROR) {
+		Object externalInstallerPlan = getSolutionFor(agentRequest, initialContext, sub.split(10));
+		if (externalInstallerPlan instanceof IProvisioningPlan provPlan
+				&& provPlan.getStatus().getSeverity() == ERROR) {
 			MultiStatus externalInstallerStatus = new MultiStatus(PI_DIRECTOR, 0, Messages.Planner_can_not_install_preq,
 					null);
-			externalInstallerStatus.add(((IProvisioningPlan) externalInstallerPlan).getStatus());
+			externalInstallerStatus.add(provPlan.getStatus());
 			IProvisioningPlan plan = engine.createPlan(initialRequest.getProfile(), initialContext);
 			plan.setStatus(externalInstallerStatus);
 			IProvisioningPlan installerPlan = engine.createPlan(agentProfile, initialContext);
@@ -734,7 +703,7 @@ public class SimplePlanner implements IPlanner {
 	private IProvisioningPlan createInstallerPlanForCohostedCase(IProfile profile, ProfileChangeRequest initialRequest,
 			IProvisioningPlan initialPlan, Collection<IInstallableUnit> unattachedState,
 			Collection<IInstallableUnit> expectedState, ProvisioningContext initialContext, SubMonitor monitor) {
-		Collection<IRequirement> metaRequirements = initialRequest.getRemovals().size() == 0
+		Collection<IRequirement> metaRequirements = initialRequest.getRemovals().isEmpty()
 				? areMetaRequirementsSatisfied(profile, expectedState, initialPlan)
 				: extractMetaRequirements(expectedState, initialPlan);
 		if (metaRequirements == null || metaRequirements.isEmpty())
@@ -755,28 +724,26 @@ public class SimplePlanner implements IPlanner {
 		for (String removedPropertie : removedProperties) {
 			agentRequest.removeProfileProperty(removedPropertie);
 		}
-		Map<IInstallableUnit, List<String>> removedIUProperties = initialRequest
-				.getInstallableUnitProfilePropertiesToRemove();
-		for (Map.Entry<IInstallableUnit, List<String>> entry : removedIUProperties.entrySet()) {
-			for (String propKey : entry.getValue()) {
-				agentRequest.removeInstallableUnitProfileProperty(entry.getKey(), propKey);
+		initialRequest.getInstallableUnitProfilePropertiesToRemove().forEach((iu, propertyKeys) -> {
+			for (String propKey : propertyKeys) {
+				agentRequest.removeInstallableUnitProfileProperty(iu, propKey);
 			}
-		}
+		});
 
 		if (previousMetaRequirementIU != null)
 			agentRequest.remove(previousMetaRequirementIU);
 		agentRequest.add(metaRequirementIU);
 
 		ProvisioningContext agentCtx = new ProvisioningContext(agent);
-		agentCtx.setMetadataRepositories(new URI[0]);
-		ArrayList<IInstallableUnit> extraIUs = new ArrayList<>(unattachedState);
+		agentCtx.setMetadataRepositories();
+		List<IInstallableUnit> extraIUs = new ArrayList<>(unattachedState);
 		agentCtx.setExtraInstallableUnits(extraIUs);
 		Object agentSolution = getSolutionFor(agentRequest, agentCtx, monitor.newChild(3));
-		if (agentSolution instanceof IProvisioningPlan
-				&& ((IProvisioningPlan) agentSolution).getStatus().getSeverity() == ERROR) {
+		if (agentSolution instanceof IProvisioningPlan solutionPlan
+				&& solutionPlan.getStatus().getSeverity() == ERROR) {
 			MultiStatus agentStatus = new MultiStatus(PI_DIRECTOR, 0,
 					Messages.Planner_actions_and_software_incompatible, null);
-			agentStatus.add(((IProvisioningPlan) agentSolution).getStatus());
+			agentStatus.add(solutionPlan.getStatus());
 			IProvisioningPlan plan = engine.createPlan(initialRequest.getProfile(), initialContext);
 			plan.setStatus(agentStatus);
 			IProvisioningPlan installerPlan = engine.createPlan(initialRequest.getProfile(), initialContext);
@@ -789,7 +756,7 @@ public class SimplePlanner implements IPlanner {
 		// the profile and the solution we just computed
 		Collection<IInstallableUnit> agentState = ((Projector) agentSolution).extractSolution();
 		agentState.remove(metaRequirementIU); // Remove the fake IU
-		agentState = AttachmentHelper.attachFragments(agentState.iterator(),
+		agentState = AttachmentHelper.attachFragments(agentState.stream(),
 				((Projector) agentSolution).getFragmentAssociation());
 
 		ProvisioningContext noRepoContext = createNoRepoContext(initialRequest);
@@ -797,14 +764,13 @@ public class SimplePlanner implements IPlanner {
 		Object initialSolution = getSolutionFor(
 				new ProfileChangeRequest(new EverythingOptionalProfile(initialRequest.getProfile())), noRepoContext,
 				new NullProgressMonitor());
-		if (initialSolution instanceof IProvisioningPlan) {
-			LogHelper.log(new Status(ERROR, PI_DIRECTOR, "The resolution of the previous state contained in profile " //$NON-NLS-1$
+		if (initialSolution instanceof IProvisioningPlan plan) {
+			LogHelper.log(Status.error("The resolution of the previous state contained in profile " //$NON-NLS-1$
 					+ initialRequest.getProfile().getProfileId() + " version " //$NON-NLS-1$
 					+ initialRequest.getProfile().getTimestamp() + " failed.")); //$NON-NLS-1$
-			return (IProvisioningPlan) initialSolution;
+			return plan;
 		}
-		Iterator<IInstallableUnit> profileState = initialRequest.getProfile().query(QueryUtil.createIUAnyQuery(), null)
-				.iterator();
+		var profileState = initialRequest.getProfile().query(QueryUtil.createIUAnyQuery(), null).stream();
 		Collection<IInstallableUnit> initialState = AttachmentHelper.attachFragments(profileState,
 				((Projector) initialSolution).getFragmentAssociation());
 
@@ -822,7 +788,7 @@ public class SimplePlanner implements IPlanner {
 		// Compute the attachment of the new state if not provided
 		if (newState == null) {
 			newState = newSolution.extractSolution();
-			newState = AttachmentHelper.attachFragments(newState.iterator(), newSolution.getFragmentAssociation());
+			newState = AttachmentHelper.attachFragments(newState.stream(), newSolution.getFragmentAssociation());
 		}
 		ProvisioningContext noRepoContext = createNoRepoContext(request);
 
@@ -830,14 +796,13 @@ public class SimplePlanner implements IPlanner {
 		Object initialSolution = getSolutionFor(
 				new ProfileChangeRequest(new EverythingOptionalProfile(request.getProfile())), noRepoContext,
 				new NullProgressMonitor());
-		if (initialSolution instanceof IProvisioningPlan) {
-			LogHelper.log(new Status(ERROR, PI_DIRECTOR,
+		if (initialSolution instanceof IProvisioningPlan plan) {
+			LogHelper.log(Status.error(
 					"The resolution of the previous state contained in profile " + request.getProfile().getProfileId() //$NON-NLS-1$
 							+ " version " + request.getProfile().getTimestamp() + " failed.")); //$NON-NLS-1$//$NON-NLS-2$
-			return (IProvisioningPlan) initialSolution;
+			return plan;
 		}
-		Iterator<IInstallableUnit> profileState = request.getProfile().query(QueryUtil.createIUAnyQuery(), null)
-				.iterator();
+		Stream<IInstallableUnit> profileState = request.getProfile().query(QueryUtil.createIUAnyQuery(), null).stream();
 		Collection<IInstallableUnit> initialState = AttachmentHelper.attachFragments(profileState,
 				((Projector) initialSolution).getFragmentAssociation());
 
@@ -847,8 +812,8 @@ public class SimplePlanner implements IPlanner {
 
 	private ProvisioningContext createNoRepoContext(ProfileChangeRequest request) {
 		ProvisioningContext noRepoContext = new ProvisioningContext(agent);
-		noRepoContext.setMetadataRepositories(new URI[0]);
-		noRepoContext.setArtifactRepositories(new URI[0]);
+		noRepoContext.setMetadataRepositories();
+		noRepoContext.setArtifactRepositories();
 		noRepoContext.setProperty(INCLUDE_PROFILE_IUS, Boolean.FALSE.toString());
 		noRepoContext.setExtraInstallableUnits(new ArrayList<>(request.getProfile()
 				.query(QueryUtil.createIUAnyQuery(), new NullProgressMonitor()).toUnmodifiableSet()));
@@ -874,14 +839,13 @@ public class SimplePlanner implements IPlanner {
 		description.setVersion(version);
 		description.addRequirements(metaRequirements);
 
-		ArrayList<IProvidedCapability> providedCapabilities = new ArrayList<>();
+		List<IProvidedCapability> providedCapabilities = new ArrayList<>();
 		IProvidedCapability providedCapability = MetadataFactory
 				.createProvidedCapability(IInstallableUnit.NAMESPACE_IU_ID, id, version);
 		providedCapabilities.add(providedCapability);
 		description.addProvidedCapabilities(providedCapabilities);
 
-		IInstallableUnit actionsIU = MetadataFactory.createInstallableUnit(description);
-		return actionsIU;
+		return MetadataFactory.createInstallableUnit(description);
 	}
 
 	private IInstallableUnit createIURepresentingTheProfile(Set<IRequirement> allRequirements) {
@@ -914,7 +878,7 @@ public class SimplePlanner implements IPlanner {
 		}
 		// Remove the iu properties associated to the ius removed and the iu properties
 		// being removed as well
-		if (removalRequested.size() != 0) {
+		if (!removalRequested.isEmpty()) {
 			for (Iterator<IInstallableUnit> iterator = alreadyInstalled.iterator(); iterator.hasNext();) {
 				IInstallableUnit iu = iterator.next();
 				for (IInstallableUnit removed : removalRequested) {
