@@ -689,10 +689,8 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 				}
 				if (add) {
 					filtered.add(element);
-				} else {
-					if (associateListener != null)
-						associateListener.filteredOut(element);
-				}
+				} else if (associateListener != null)
+					associateListener.filteredOut(element);
 			}
 			return filtered.toArray();
 		}
@@ -725,7 +723,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * methods on this viewer.
 	 * <p>
 	 * This method was introduced to support multiple equal elements in a viewer
-	 * (@see {@link AbstractTreeViewer}). Multiple equal elements are only
+	 * (see {@link AbstractTreeViewer}). Multiple equal elements are only
 	 * supported if the element map is enabled by calling
 	 * {@link #setUseHashlookup(boolean)} and passing <code>true</code>.
 	 * </p>
@@ -850,9 +848,11 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 */
 	protected Object[] getFilteredChildren(Object parent) {
 		Object[] result = getRawChildren(parent);
+		if (result.length == 0) {
+			return result;
+		}
 		if (filters != null) {
-			for (Object element : filters) {
-				ViewerFilter f = (ViewerFilter) element;
+			for (ViewerFilter f : filters) {
 				Object[] filteredResult = f.filter(this, parent, result);
 				if (associateListener != null && filteredResult.length != result.length) {
 					notifyFilteredOut(result, filteredResult);
@@ -1210,7 +1210,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 				handleDoubleSelect(e);
 			}
 		});
-		handler.addPostSelectionListener(widgetSelectedAdapter(e -> handlePostSelect(e)));
+		handler.addPostSelectionListener(widgetSelectedAdapter(this::handlePostSelect));
 		handler.addOpenListener(StructuredViewer.this::handleOpen);
 	}
 
@@ -1414,7 +1414,17 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 
 	@Override
 	public void refresh() {
-		refresh(getRoot());
+		Control control = getControl();
+		if (control != null) {
+			control.setRedraw(false);
+		}
+		try {
+			refresh(getRoot());
+		} finally {
+			if (control != null) {
+				control.setRedraw(true);
+			}
+		}
 	}
 
 	/**
@@ -1707,10 +1717,8 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	/**
 	 * Sets this viewer's sorter and triggers refiltering and resorting of this
 	 * viewer's element. Passing <code>null</code> turns sorting off.
-	 * <p>
 	 *
 	 * @deprecated use <code>setComparator()</code> instead.
-	 *             </p>
 	 *
 	 * @param sorter
 	 *            a viewer sorter, or <code>null</code> if none
