@@ -15,12 +15,33 @@
 package org.eclipse.pde.internal.ui.search.dependencies;
 
 import java.lang.reflect.InvocationTargetException;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.Map;
+import java.util.Set;
+
 import org.eclipse.core.resources.IProject;
-import org.eclipse.core.runtime.*;
-import org.eclipse.jdt.core.*;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.SubMonitor;
+import org.eclipse.jdt.core.Flags;
+import org.eclipse.jdt.core.IField;
+import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.IMethod;
+import org.eclipse.jdt.core.IPackageFragment;
+import org.eclipse.jdt.core.IType;
+import org.eclipse.jdt.core.ITypeRoot;
+import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.core.Signature;
 import org.eclipse.osgi.util.NLS;
-import org.eclipse.pde.internal.core.ibundle.*;
+import org.eclipse.pde.internal.core.ibundle.IBundle;
+import org.eclipse.pde.internal.core.ibundle.IBundlePluginModelBase;
+import org.eclipse.pde.internal.core.ibundle.IManifestHeader;
 import org.eclipse.pde.internal.core.text.bundle.ExportPackageHeader;
 import org.eclipse.pde.internal.core.text.bundle.ExportPackageObject;
 import org.eclipse.pde.internal.core.util.PDEJavaHelper;
@@ -30,8 +51,8 @@ import org.osgi.framework.Constants;
 
 public class CalculateUsesOperation extends WorkspaceModifyOperation {
 
-	private IProject fProject;
-	private IBundlePluginModelBase fModel;
+	private final IProject fProject;
+	private final IBundlePluginModelBase fModel;
 
 	public CalculateUsesOperation(IProject project, IBundlePluginModelBase model) {
 		fProject = project;
@@ -197,9 +218,9 @@ public class CalculateUsesOperation extends WorkspaceModifyOperation {
 		Set<String> usesPkgs = pkgsAndUses.get(pkgName);
 		usesPkgs.remove(pkgName);
 		StringBuilder buffer = null;
-		Iterator<?> it = usesPkgs.iterator();
+		Iterator<String> it = usesPkgs.iterator();
 		while (it.hasNext()) {
-			String usedPkgName = (String) it.next();
+			String usedPkgName = it.next();
 			if (usedPkgName.startsWith("java.")) { //$NON-NLS-1$
 				// we should not include java.* packages (bug 167968)
 				it.remove();
